﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Telerik.Windows.Core;

namespace GanttChooseSummaryContainer
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            this.GanttView.ExpandCollapseService.HierarchicalCollectionAdapter.CollectionChanged += HierarchicalCollectionAdapter_CollectionChanged;
        }

        void HierarchicalCollectionAdapter_CollectionChanged(object sender, System.Collections.Specialized.NotifyCollectionChangedEventArgs e)
        {
            if (e.OldItems != null)
            {
                var items = e.OldItems.OfType<HierarchicalItem>();
                if (items != null && items.Count() > 0)
                {
                    var parent = FindParent(items.First().SourceItem as CustomGanttTask);
                    if (parent != null)
                    {
                        parent.IsExpanded = false;
                    }
                }
            }

            if (e.NewItems != null)
            {
                var items = e.NewItems.OfType<HierarchicalItem>();
                if (items != null && items.Count() > 0)
                {
                    var parent = FindParent(items.First().SourceItem as CustomGanttTask);
                    if (parent != null)
                    {
                        parent.IsExpanded = true;
                    }
                }
            }
        }

        private CustomGanttTask FindParent(CustomGanttTask task)
        {
            var parentCollection = (this.DataContext as ViewModel).Tasks;
            foreach (var ctask in parentCollection)
            {
                if (ctask == task)
                {
                    return null;
                }
            }

            var i = 0;
            var res = FindParent(task, parentCollection[i]);
            while (res == null && i < parentCollection.Count() - 1)
            {
                i++;
                res = FindParent(task, parentCollection[i]);
            }

            return res;
        }

        private CustomGanttTask FindParent(CustomGanttTask task, CustomGanttTask parent)
        {
            foreach (var ctask in parent.Children)
            {
                if (task == ctask)
                {
                    return parent;
                }
            }

            var i = 0;
            var parentCollection = parent.Children.OfType<CustomGanttTask>().ToArray();
            if (parentCollection.Count() > 0)
            {
                var res = FindParent(task, parentCollection[i]);
                while (res == null && i < parentCollection.Count() - 1)
                {
                    i++;
                    res = FindParent(task, parentCollection[i]);
                }

                return res;
            }

            return null;
        }
    }
}
